-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: PetDPS")

L:RegisterTranslations("enUS", function() return {
	["Pet Damage per Second"] = true,

	["PetDPS: "] = true,

	["DPS"] = true,
	["Pet"] = true,
	["#"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Pet Damage per Second"] = "소환수 초당 피해량",

	["PetDPS: "] = "소환수DPS: ",

	["DPS"] = "DPS",
	["Pet"] = "소환수",
	["#"] = "#",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local tablet = AceLibrary("Tablet-2.0")

local percentString = "(%d%%)"

local playerName = nil

local event = {
	eventType = "Damage",
	sourceID = "pet",
}

local data = nil
local position = nil
local dirty = nil
local lastUpdateTime
local seconds = nil
local damageDone = 0

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule("PetDPS", "Parser-3.0")
mod.revision = tonumber(("$Revision: 29290 $"):sub(12, -3)) or 1
mod.version = 2

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleRegister()
	playerName = UnitName("player")
end

function mod:OnModuleEnable()
	self:RegisterParserEvent(event, "OnParserEvent")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
end

function mod:OnReset()
	if type(data) == "table" then
		data = self:del(data)
	end

	data = self:new()
	data[playerName] = 0
	damageDone = 0
	seconds = 0
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetRevision() return self.revision end
function mod:GetDisplayName() return L["Pet Damage per Second"] end
function mod:GetBroadcastData()
	dirty = nil
	return data[playerName]
end

function mod:IsDirty()
	return dirty
end

function mod:OnRemoteData(sender, input)
	-- remote dps is placed in the damage table, this is done so we don't need to recalc everybody else's DPS.
	data[sender] = input
end

function mod:PLAYER_REGEN_ENABLED()
	lastUpdateTime = nil
end

function mod:OnParserEvent(event)
	assert(event.sourceID == "pet", "Not supposed to get combat events from people except ourselves.")
	if event.amount then
		local newTime = GetTime()
		local timeSinceLastUpdate
		-- on the offhand chance that lastUpdateTime is nil at this point (if somehow we do damage before a regen disabled event fires)
		-- make sure that we have a 
		if not lastUpdateTime then
			timeSinceLastUpdate = 0.1
		else
			timeSinceLastUpdate = newTime - lastUpdateTime
		end
		lastUpdateTime = newTime
		seconds = seconds + timeSinceLastUpdate
		
		damageDone = damageDone + event.amount
		
		local newDPS = math.floor(damageDone / seconds)
		dirty = newDPS - (data[playerName] or 0)
		data[playerName] = newDPS
	end
end

function mod:GetData(player)
	if player then
		return data[player]
	else
		return data
	end
end

function mod:GetDisplayText()
	if data and data[playerName] > 0 then
		return L["PetDPS: "] .. (type(position) ~= "nil" and tostring(position) .. ". " or "") .. math.floor(data[playerName])
	end
	return nil
end

